==> bplan-base-globals-1.1.0-0b4347.zip: lang/tr/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'tr',
    'language' => 'Türkçe',
    'locale' => 'tr_TR',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value ₺',
    'currency.format.negative' => '-:value ₺',
    'currency.iso4217.alpha'   => 'TRY',
    'currency.iso4217.numeric' => 949,
    'currency.name'            => 'Türk Lirası',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Kuruş',
    'currency.subunit.symbol'  => 'kr',
    'currency.symbol'          => '₺',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktif Et',
    'action.add'           => 'Ekle',
    'action.cancel'        => 'İptal Et',
    'action.cancel-upload' => 'Yüklemeyi İptal Et',
    'action.change'        => 'Değiştir',
    'action.close'         => 'Kapat',
    'action.confirm'       => 'Onayla',
    'action.deactivate'    => 'Pasif Et',
    'action.delete'        => 'Sil',
    'action.edit'          => 'Düzenle',
    'action.import'        => 'İçe Aktar',
    'action.print'         => 'Yazdır',
    'action.save'          => 'Kaydet',
    'action.search'        => 'Ara',
    'action.sync'          => 'Senkronize Et',
    'action.upload'        => 'Dosya Yükle',
    'action.verify'        => 'Doğrula',
    'action.view'          => 'Görüntüle',

    'languages' => [
        'bg' => 'Bulgarca',
        'de' => 'Almanca',
        'en' => 'İngilizce',
        'es' => 'İspanyolca',
        'fr' => 'Fransızca',
        'hu' => 'Macarca',
        'it' => 'İtalyanca',
        'lt' => 'Litvanca',
        'pl' => 'Lehçe',
        'ro' => 'Rumence',
        'ru' => 'Rusça',
        'tr' => 'Türkçe',
        'uk' => 'Ukraynaca',
    ],

    'option.yes' => 'Evet',
    'option.no'  => 'Hayır',

    'required-hint'   => 'İşaretli alanlar (<span class="required-marker">:marker</span>) zorunludur',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Lütfen Seçin -- ',

    'status.active'   => 'Aktif',
    'status.expired'  => 'Süresi Dolmuş',
    'status.inactive' => 'Pasif',
    'status.invalid'  => 'Geçersiz',
    'status.loading'  => 'Yükleniyor...',
    'status.not-set'  => 'Ayarlanmamış',
    'status.valid'    => 'Geçerli',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/tr/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'tr',
    'language' => 'Türkçe',
    'locale' => 'tr_TR',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value ₺',
    'currency.format.negative' => '-:value ₺',
    'currency.iso4217.alpha'   => 'TRY',
    'currency.iso4217.numeric' => 949,
    'currency.name'            => 'Türk Lirası',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Kuruş',
    'currency.subunit.symbol'  => 'kr',
    'currency.symbol'          => '₺',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktif Et',
    'action.add'           => 'Ekle',
    'action.cancel'        => 'İptal Et',
    'action.cancel-upload' => 'Yüklemeyi İptal Et',
    'action.change'        => 'Değiştir',
    'action.close'         => 'Kapat',
    'action.confirm'       => 'Onayla',
    'action.deactivate'    => 'Pasif Et',
    'action.delete'        => 'Sil',
    'action.edit'          => 'Düzenle',
    'action.import'        => 'İçe Aktar',
    'action.print'         => 'Yazdır',
    'action.save'          => 'Kaydet',
    'action.search'        => 'Ara',
    'action.sync'          => 'Senkronize Et',
    'action.upload'        => 'Dosya Yükle',
    'action.verify'        => 'Doğrula',
    'action.view'          => 'Görüntüle',

    'languages' => [
        'bg' => 'Bulgarca',
        'de' => 'Almanca',
        'en' => 'İngilizce',
        'es' => 'İspanyolca',
        'fr' => 'Fransızca',
        'hu' => 'Macarca',
        'it' => 'İtalyanca',
        'lt' => 'Litvanca',
        'pl' => 'Lehçe',
        'ro' => 'Rumence',
        'ru' => 'Rusça',
        'tr' => 'Türkçe',
        'uk' => 'Ukraynaca',
    ],

    'option.yes' => 'Evet',
    'option.no'  => 'Hayır',

    'required-hint'   => 'İşaretli alanlar (<span class="required-marker">:marker</span>) zorunludur',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Seçenek mevcut değil',
    'select-option.please-select'        => ' -- Lütfen Seçin -- ',

    'status.active'   => 'Aktif',
    'status.expired'  => 'Süresi Dolmuş',
    'status.inactive' => 'Pasif',
    'status.invalid'  => 'Geçersiz',
    'status.loading'  => 'Yükleniyor...',
    'status.not-set'  => 'Ayarlanmamış',
    'status.valid'    => 'Geçerli',

];
